@@ -1,5 +1,6 @@
 /*
  * Copyright 1994-2018 Brad Lanam, Walnut Creek, CA
+ * Copyright 2023 Brad Lanam, Pleasant Hill, CA
  */
 
 /********************************************************/
@@ -111,13 +112,7 @@ extern int debug;
 # define DI_GETDISKINFO_DEF 1
 
 void
-# if _proto_stdc
 di_getDiskInfo (diDiskInfo_t **diskInfo, int *diCount)
-# else
-di_getDiskInfo (diskInfo, diCount)
-    diDiskInfo_t **diskInfo;
-    int *diCount;
-# endif
 {
     diDiskInfo_t     *diptr;
     int             i;
@@ -235,13 +230,7 @@ di_getDiskInfo (diskInfo, diCount)
 # define DI_GETDISKINFO_DEF 1
 
 void
-# if _proto_stdc
 di_getDiskInfo (diDiskInfo_t **diskInfo, int *diCount)
-# else
-di_getDiskInfo (diskInfo, diCount)
-    diDiskInfo_t **diskInfo;
-    int *diCount;
-# endif
 {
     diDiskInfo_t     *diptr;
     int             i;
@@ -330,13 +319,7 @@ di_getDiskInfo (diskInfo, diCount)
 # define DI_GETDISKINFO_DEF 1
 
 void
-# if _proto_stdc
 di_getDiskInfo (diDiskInfo_t **diskInfo, int *diCount)
-# else
-di_getDiskInfo (diskInfo, diCount)
-    diDiskInfo_t **diskInfo;
-    int *diCount;
-# endif
 {
     diDiskInfo_t     *diptr;
     int             i;
@@ -405,13 +388,7 @@ di_getDiskInfo (diskInfo, diCount)
 # define MSDOS_BUFFER_SIZE          256
 
 void
-# if _proto_stdc
 di_getDiskInfo (diDiskInfo_t **diskInfo, int *diCount)
-# else
-di_getDiskInfo (diskInfo, diCount)
-    diDiskInfo_t **diskInfo;
-    int *diCount;
-# endif
 {
     diDiskInfo_t         *diptr;
     int                 i;
@@ -536,13 +513,7 @@ di_getDiskInfo (diskInfo, diCount)
 
 #if ! defined (DI_GETDISKINFO_DEF)
 void
-#  if _proto_stdc
 di_getDiskInfo (diDiskInfo_t **diskInfo, int *diCount)
-#  else
-di_getDiskInfo (diskInfo, diCount)
-    diDiskInfo_t **diskInfo;
-    int *diCount;
-#  endif
 {
     if (debug > 0) { printf ("# getDiskInfo: empty\n"); }
     return;
