@@ -1,6 +1,7 @@
 #!/bin/sh
 #
 # Copyright 2001-2018 Brad Lanam, Walnut Creek, California USA
+# Copyright 2020 Brad Lanam Pleasant Hill CA
 #
 
 #
@@ -124,11 +125,11 @@ check_using_gcc () {
   printlabel _MKCONFIG_USING_GCC "Using gcc/g++"
 
   # check for gcc...
-  ${CC} -v 2>&1 | grep 'gcc version' > /dev/null 2>&1
+  ${CC} -v 2>&1 | grep 'gcc version' >/dev/null 2>&1
   rc=$?
   if [ $rc -eq 0 ]; then
-      puts "found gcc" >&9
-      usinggcc="Y"
+    puts "found gcc" >&9
+    usinggcc="Y"
   fi
 
   case ${CC} in
@@ -170,7 +171,8 @@ check_using_gnu_ld () {
   printlabel _MKCONFIG_USING_GNU_LD "Using gnu ld"
 
   # check for gnu ld...
-  ld -v 2>&1 | grep 'GNU ld' > /dev/null 2>&1
+  # dragonfly bsd 5.8.1 gcc8 reports 'GNU gold' rather than 'GNU ld'.
+  ld -v 2>&1 | grep 'GNU' > /dev/null 2>&1
   rc=$?
   if [ $rc -eq 0 ]; then
       puts "found gnu ld" >&9
@@ -316,58 +318,101 @@ check_addcflag () {
 
   printlabel CFLAGS_APPLICATION "Add C flag: ${flag}"
 
-  puts "#include <stdio.h>
-main () { return 0; }" > t.c
-  puts "# test ${flag}" >&9
-  # need to set w/all cflags; gcc doesn't always error out otherwise
-  TMPF=t$$.txt
-  setcflags
-  ${CC} ${CFLAGS} ${flag} t.c > $TMPF 2>&1
-  rc=$?
-  if [ $rc -ne 0 ]; then
-    flag=0
-  fi
-  grep -i "warning.*${flag}" $TMPF > /dev/null 2>&1
-  rc=$?
-  if [ $rc -eq 0 ]; then
-    flag=0
-  fi
-  cat $TMPF >&9
-  rm -f $TMPF > /dev/null 2>&1
-  printyesno $name ${flag}
+  test_cflag "$flag"
+  printyesno $name "${flag}"
   if [ $flag != 0 ]; then
     doappend CFLAGS_APPLICATION " $flag"
     setdata ${_MKCONFIG_PREFIX} CFLAGS_APPLICATION "$CFLAGS_APPLICATION"
   fi
 }
 
+check_pkg_cflags () {
+  name=$1
+  pkgname=$2
+  pkgpath=$3
+
+  OPKG_CONFIG_PATH=$PKG_CONFIG_PATH
+  if [ "$pkgpath" != "" ]; then
+    if [ "$PKG_CONFIG_PATH" != "" ]; then
+      doappend PKG_CONFIG_PATH :
+    fi
+    doappend PKG_CONFIG_PATH $pkgpath
+  fi
+  export PKG_CONFIG_PATH
+  tcflags=`${pkgconfigcmd} --cflags $pkgname`
+  unset PKG_CONFIG_PATH
+  if [ "$OPKG_CONFIG_PATH" != "" ]; then
+    PKG_CONFIG_PATH=$OPKG_CONFIG_PATH
+  fi
+  test_cflag "$tcflags"
+  printyesno_val $name "${flag}"
+  if [ "$flag" != 0 ]; then
+    doappend CFLAGS_APPLICATION " $flag"
+    setdata ${_MKCONFIG_PREFIX} CFLAGS_APPLICATION "$CFLAGS_APPLICATION"
+  fi
+}
+
+check_pkg_include () {
+  name=$1
+  pkgname=$2
+  pkgpath=$3
+
+  OPKG_CONFIG_PATH=$PKG_CONFIG_PATH
+  if [ "$pkgpath" != "" ]; then
+    if [ "$PKG_CONFIG_PATH" != "" ]; then
+      doappend PKG_CONFIG_PATH :
+    fi
+    doappend PKG_CONFIG_PATH $pkgpath
+  fi
+  export PKG_CONFIG_PATH
+  tcflags=`${pkgconfigcmd} --cflags-only-I $pkgname`
+  unset PKG_CONFIG_PATH
+  if [ "$OPKG_CONFIG_PATH" != "" ]; then
+    PKG_CONFIG_PATH=$OPKG_CONFIG_PATH
+  fi
+  test_cflag "$tcflags"
+  printyesno_val $name "${flag}"
+  if [ "$flag" != 0 ]; then
+    doappend CFLAGS_APPLICATION " $flag"
+    setdata ${_MKCONFIG_PREFIX} CFLAGS_APPLICATION "$CFLAGS_APPLICATION"
+  fi
+}
+
+check_pkg_libs () {
+  name=$1
+  pkgname=$2
+  pkgpath=$3
+
+  OPKG_CONFIG_PATH=$PKG_CONFIG_PATH
+  if [ "$pkgpath" != "" ]; then
+    if [ "$PKG_CONFIG_PATH" != "" ]; then
+      doappend PKG_CONFIG_PATH :
+    fi
+    doappend PKG_CONFIG_PATH $pkgpath
+    export PKG_CONFIG_PATH
+  fi
+  export PKG_CONFIG_PATH
+  tldflags=`${pkgconfigcmd} --libs $pkgname`
+  unset PKG_CONFIG_PATH
+  if [ "$OPKG_CONFIG_PATH" != "" ]; then
+    PKG_CONFIG_PATH=$OPKG_CONFIG_PATH
+  fi
+  test_ldflags "$tldflags"
+  printyesno_val $name "$flag"
+  if [ "$flag" != 0 ]; then
+    doappend LDFLAGS_LIBS_APPLICATION " $flag"
+    setdata ${_MKCONFIG_PREFIX} LDFLAGS_LIBS_APPLICATION "$LDFLAGS_LIBS_APPLICATION"
+  fi
+}
+
 check_addldflag () {
   name=$1
   flag=$2
 
   printlabel LDFLAGS_APPLICATION "Add LD flag: ${flag}"
 
-  setcflags
-  setldflags
-  setlibs
-  puts "#include <stdio.h>
-main () { return 0; }" > t.c
-  puts "# test ${flag}" >&9
-  # need to set w/all cflags/ldflags; gcc doesn't always error out otherwise
-  TMPF=t$$.txt
-  ${CC} ${CFLAGS} ${LDFLAGS} ${flag} -o t t.c > $TMPF 2>&1
-  rc=$?
-  if [ $rc -ne 0 ]; then
-    flag=0
-  fi
-  grep -i "warning.*${flag}" $TMPF > /dev/null 2>&1
-  rc=$?
-  if [ $rc -eq 0 ]; then
-    flag=0
-  fi
-  cat $TMPF >&9
-  rm -f $TMPF > /dev/null 2>&1
-  printyesno $name ${flag}
+  test_ldflags "$flag"
+  printyesno $name "$flag"
   if [ $flag != 0 ]; then
     doappend ldflags_application " $flag"
     _setflags ldflags_application LDFLAGS_APPLICATION
@@ -518,7 +563,8 @@ check_cflags_shared () {
   if [ "$_MKCONFIG_USING_GCC" != Y ]; then
     case ${_MKCONFIG_SYSTYPE} in
       CYGWIN*|MSYS*|MINGW*)
-        doappend cflags_shared " -fPIC"
+        # apparently, clang does not need this any more.
+        doappend cflags_shared ""
         ;;
       Darwin)
         doappend cflags_shared " -fno-common"
@@ -574,6 +620,9 @@ check_ldflags_shared () {
       AIX)
         doappend ldflags_shared_liblink " -G"
         ;;
+      Darwin)
+        doappend ldflags_shared_liblink " -dynamiclib"
+        ;;
       HP-UX)
         doappend ldflags_shared_liblink " -b"
         ;;
@@ -582,7 +631,7 @@ check_ldflags_shared () {
         doappend ldflags_shared_liblink " -shared"
         ;;
       OSF1)
-        doappend ldflags_shared_liblink " -msym -no_archive"
+        doappend ldflags_shared_liblink " -msym -no_archive -shared"
         ;;
       SCO_SV)
         doappend ldflags_shared_liblink " -G"
@@ -601,12 +650,6 @@ check_ldflags_shared () {
     doappend ldflags_shared_liblink " -shared"
   fi
 
-  case ${_MKCONFIG_SYSTYPE} in
-    Darwin)
-      doappend ldflags_shared_liblink " -dynamiclib"
-      ;;
-  esac
-
   _read_option LDFLAGS_SHARED ""
   if [ "z$LDFLAGS_SHARED" != z ]; then
     ldflags_shared_user="${LDFLAGS_SHARED}"
@@ -638,6 +681,9 @@ check_sharednameflag () {
       SunOS)
         SHLDNAMEFLAG="-Wl,-h "
         ;;
+      *)
+        SHLDNAMEFLAG=""
+        ;;
     esac
   fi
 
@@ -648,31 +694,29 @@ check_sharednameflag () {
 check_shareexeclinkflag () {
   printlabel LDFLAGS_EXEC_LINK "shared executable link flag "
 
-  LDFLAGS_EXEC_LINK="-Bdynamic "
-  if [ "$_MKCONFIG_USING_GCC" != Y ]; then
+  LDFLAGS_EXEC_LINK="-Bdynamic"
+  if [ "$_MKCONFIG_USING_GNU_LD" != Y ]; then
     case ${_MKCONFIG_SYSTYPE} in
       AIX)
-        LDFLAGS_EXEC_LINK="-brtl -bdynamic "
-        ;;
-      Darwin)
-        LDFLAGS_EXEC_LINK=
+        LDFLAGS_EXEC_LINK="-brtl -bdynamic"
         ;;
       HP-UX)
-        LDFLAGS_EXEC_LINK="+Z"
+        LDFLAGS_EXEC_LINK=""
         ;;
       OSF1)
-        LDFLAGS_EXEC_LINK="-msym -no_archive "
-        ;;
-      SCO_SV)
-        LDFLAGS_EXEC_LINK=
+        LDFLAGS_EXEC_LINK=""
         ;;
       SunOS)
         # -Bdynamic
         ;;
-      UnixWare)
-        LDFLAGS_EXEC_LINK=
+      *)
+        LDFLAGS_EXEC_LINK=""
         ;;
     esac
+    if [ "$_MKCONFIG_USING_GCC" = Y ]; then
+      LDFLAGS_EXEC_LINK=`echo "$LDFLAGS_EXEC_LINK" |
+          sed -e 's/^-/-Wl,-/' -e 's/^\+/-Wl,+/' -e 's/  */ -Wl,/g'`
+    fi
   fi
 
   printyesno_val LDFLAGS_EXEC_LINK "$LDFLAGS_EXEC_LINK"
@@ -685,31 +729,34 @@ check_sharerunpathflag () {
   LDFLAGS_RUNPATH="-Wl,-rpath="
   if [ "$_MKCONFIG_USING_GNU_LD" != Y ]; then
     case ${_MKCONFIG_SYSTYPE} in
-      AIX)
-        LDFLAGS_RUNPATH=
-        ;;
-      Darwin)
-        LDFLAGS_RUNPATH=
-        ;;
       HP-UX)
-        LDFLAGS_RUNPATH="-Wl,+b "
+        LDFLAGS_RUNPATH="+b "
         ;;
       IRIX*)
-        LDFLAGS_RUNPATH="-Wl,-rpath "
+        LDFLAGS_RUNPATH="-rpath "
         ;;
       OSF1)
         LDFLAGS_RUNPATH="-rpath "
         ;;
       SCO_SV)
-        LDFLAGS_RUNPATH="-Wl,-R "
+        LDFLAGS_RUNPATH="-R "
         ;;
       SunOS)
-        LDFLAGS_RUNPATH="-Wl,-R"
+        LDFLAGS_RUNPATH="-R"
         ;;
       UnixWare)
-        LDFLAGS_RUNPATH="-Wl,-R "
+        LDFLAGS_RUNPATH="-R "
+        ;;
+      *)
+        LDFLAGS_RUNPATH=""
         ;;
     esac
+    if [ "$_MKCONFIG_USING_GCC" = Y ]; then
+      # the trailing space will be converted to ' -Wl,' and
+      # the library runpath will be appended by mkcl.sh
+      LDFLAGS_RUNPATH=`echo "$LDFLAGS_RUNPATH" |
+          sed -e 's/^-/-Wl,-/' -e 's/^\+/-Wl,+/' -e 's/  */ -Wl,/g'`
+    fi
   fi
 
   printyesno_val LDFLAGS_RUNPATH "$LDFLAGS_RUNPATH"
@@ -805,3 +852,13 @@ check_findpc () {
     setdata ${_MKCONFIG_PREFIX} pc_${cfile} N
   fi
 }
+
+check_standard_cc () {
+  check_cc
+  check_using_gcc
+  check_using_gnu_ld
+  check_using_clang
+  check_using_cplusplus
+  check_cflags
+  check_ldflags
+}
